@@ -4,8 +4,10 @@ import os
 import tempfile
 
 from celery.utils.log import get_task_logger
-from django.conf import settings
+import dateutil.parser
 from django.contrib.gis.geos import GEOSGeometry, Polygon
+from django.utils.timezone import make_aware
+from django_large_image.tilesource import get_bounds
 import numpy as np
 from osgeo import gdal
 import rasterio
@@ -15,8 +17,8 @@ import rasterio.shutil
 import rasterio.warp
 from rasterio.warp import Resampling, calculate_default_transform, reproject
 from rgd.models.constants import DB_SRID
-from rgd.utility import get_or_create_no_commit
-from rgd_imagery.large_image_utilities import get_tile_bounds, yeild_tilesource_from_image
+from rgd.utility import get_or_create_no_commit, get_temp_dir
+from rgd_imagery.large_image_utilities import yeild_tilesource_from_image
 from rgd_imagery.models import BandMeta, Image, ImageMeta, Raster, RasterMeta
 from shapely.geometry import shape
 from shapely.ops import unary_union
@@ -36,8 +38,9 @@ def _populate_image_meta_models(image, image_meta):
         meta = tile_source.getMetadata()
         imeta = tile_source.getInternalMetadata()
         bands = tile_source.getBandInformation()
+        if isinstance(bands, list):
+            bands = {i + 1: b for i, b in enumerate(bands)}
 
-        image_meta.number_of_bands = len(bands)
         image_meta.driver = (
             imeta['driverShortName'] if 'driverShortName' in imeta else 'pil'
         )  # NOTE: assumes PIL if not using GDAL
@@ -47,7 +50,7 @@ def _populate_image_meta_models(image, image_meta):
         image_meta.save()
 
         # TODO: we need `PILFileTileSource` in large_image to support band information
-        if 'bands' in meta:
+        if bands:
             for index, band_info in bands.items():
 
                 def safe_get(key):
@@ -88,7 +91,7 @@ def load_image(image):
 
 
 def _extract_raster_outline(tile_source):
-    bounds = get_tile_bounds(tile_source)
+    bounds = get_bounds(tile_source)
     coords = np.array(
         (
             (bounds['xmin'], bounds['ymax']),
@@ -114,7 +117,7 @@ def _extract_raster_meta(image):
     with yeild_tilesource_from_image(image) as tile_source:
         meta = tile_source.getMetadata()
         imeta = tile_source.getInternalMetadata()
-        bounds = get_tile_bounds(tile_source)
+        bounds = get_bounds(tile_source)
 
         raster_meta['crs'] = tile_source.getProj4String()
         raster_meta['origin'] = [bounds['xmin'], bounds['ymin']]
@@ -140,7 +143,7 @@ def _get_valid_data_footprint(src, band_num):
     # TODO: fix transform to match this resampling
     nodata = 0
     if not src.nodata:
-        workdir = getattr(settings, 'GEODATA_WORKDIR', None)
+        workdir = get_temp_dir()
         with tempfile.TemporaryDirectory(dir=workdir) as tmpdir:
             output_path = os.path.join(tmpdir, 'temp')
             rasterio.shutil.copy(src, output_path, driver=src.driver)
@@ -161,7 +164,8 @@ def _get_valid_data_footprint(src, band_num):
             geoms.append(shape(geom))
     if geoms:
         geom = unary_union(geoms)
-        return GEOSGeometry(geom.to_wkt()).convex_hull
+        # NOTE: shapely 1.8 deprecated `to_wkt()`
+        return GEOSGeometry(geom.wkt).convex_hull
 
     raise ValueError('No valid raster footprint found.')
 
@@ -215,7 +219,7 @@ def _reproject_raster(file_path, epsg):
             # If raster already in desired CRS, return itself
             yield src
             return
-        workdir = getattr(settings, 'GEODATA_WORKDIR', None)
+        workdir = get_temp_dir()
         with tempfile.TemporaryDirectory(dir=workdir) as tmpdir:
             # Get a downsampled version of the original raster
             with _yield_downsampled_raster(src) as dsrc:
@@ -259,7 +263,7 @@ def _extract_raster_footprint(image):
     This operates on the assumption that the Image is a valid raster.
 
     """
-    with image.file.yield_local_path(vsi=True) as file_path:
+    with image.file.yield_local_path(yield_file_set=True) as file_path:
         # Reproject the raster to the DB SRID using rasterio directly rather
         #  than transforming the extracted geometry which had issues.
         with _reproject_raster(file_path, DB_SRID) as src:
@@ -299,9 +303,8 @@ def _validate_image_set_is_raster(image_set):
 
     base_image = images.pop()
     first_meta = _extract_raster_meta(base_image)
-    for image in images:
-        _extract_raster_meta(image)
-
+    # for image in images:
+    #     _extract_raster_meta(image)
     return first_meta
 
 
@@ -324,6 +327,22 @@ def populate_raster(raster):
     for k, v in meta.items():
         # Yeah. This is sketchy, but it works.
         setattr(raster_meta, k, v)
+    # Assign extra fields:
+    if raster.extra_fields:
+        date = raster.extra_fields.get('acquisition_date', None)
+        cloud_cover = raster.extra_fields.get('cloud_cover', None)
+        instrumentation = raster.extra_fields.get('instrumentation', None)
+        if date:
+            adt = dateutil.parser.isoparser().isoparse(date)
+            try:
+                raster_meta.acquisition_date = make_aware(adt)
+            except ValueError:
+                raster_meta.acquisition_date = adt
+        if cloud_cover:
+            raster_meta.cloud_cover = cloud_cover
+        if instrumentation:
+            raster.rastermeta.instrumentation = instrumentation
+
     raster_meta.save()
     return True
 
