@@ -39,19 +39,3 @@ class RasterFactory(factory.django.DjangoModelFactory):
     def _after_postgeneration(cls, instance, *args, **kwargs):
         super()._after_postgeneration(instance, *args, **kwargs)
         instance.refresh_from_db()
-
-
-class KWCOCOArchiveFactory(factory.django.DjangoModelFactory):
-    class Meta:
-        model = models.KWCOCOArchive
-
-    name = factory.Faker('sentence', nb_words=2)
-    spec_file = factory.SubFactory(ChecksumFileFactory)
-    image_archive = factory.SubFactory(ChecksumFileFactory)
-
-    # If we have an on_commit or post_save method that modifies the model, we
-    # need to refresh it afterwards.
-    @classmethod
-    def _after_postgeneration(cls, instance, *args, **kwargs):
-        super()._after_postgeneration(instance, *args, **kwargs)
-        instance.refresh_from_db()
